@@ -1,7 +1,12 @@
 #ifndef PRPACK_CSC
 #define PRPACK_CSC
 
-#include <stdint.h>
+#if !defined(_MSC_VER) && !defined (__MINGW32__) && !defined (__MINGW64__)
+#  include <stdint.h>
+#else
+#  include <stdio.h>
+typedef __int64 int64_t;
+#endif
 
 namespace prpack {
 
